agentle.mcp.models.blob\_resource\_contents
===========================================

.. automodule:: agentle.mcp.models.blob_resource_contents

   
   .. rubric:: Functions

   .. autosummary::
   
      Field
   
   .. rubric:: Classes

   .. autosummary::
   
      BlobResourceContents
      ResourceContents
   